@@ -20,7 +20,7 @@
 # IN THE SOFTWARE.
 
 __author__ = "Niklas Rosenstein <rosensteinniklas@gmail.com>"
-__version__ = "2.1.2"
+__version__ = "2.2.1"
 __all__ = [
     "Parser",
     "ParserOptions",
@@ -96,8 +96,7 @@ def parse_python_module(
     module_name: t.Optional[str] = None,
     options: t.Optional[ParserOptions] = None,
     encoding: t.Optional[str] = None,
-) -> Module:
-    ...
+) -> Module: ...
 
 
 @t.overload
@@ -107,8 +106,7 @@ def parse_python_module(
     module_name: t.Optional[str] = None,
     options: t.Optional[ParserOptions] = None,
     encoding: t.Optional[str] = None,
-) -> Module:
-    ...
+) -> Module: ...
 
 
 def parse_python_module(  # type: ignore
